@@ -5,26 +5,18 @@ use warnings;
 no warnings qw{uninitialized};
 use Apache2::ClickPath::_parse;
 use MIME::Base64 ();
-use Crypt::CBC ();
-use Crypt::Blowfish ();
-use Digest::MD5 ();
-use Digest::CRC ();
 use Class::Member qw{friendly_session
 		     tag
 		     server_map
-		     secret
-		     secret_iv
 		     session
 		     remote_session_host remote_session
 		     server_id
-		     server_name
 		     creation_time
 		     server_pid
 		     seq_number
-		     connection_id
-		     debug};
+		     connection_id};
 
-our $VERSION='1.10';
+our $VERSION='1.2';
 
 sub new {
   my $class=shift;
@@ -40,7 +32,7 @@ sub new {
     bless $I=>$class;
   }
 
-  foreach my $m (qw{friendly_session tag server_map session secret secret_iv}) {
+  foreach my $m (qw{friendly_session tag server_map session}) {
     $I->$m=$o{$m} if( exists $o{$m} );
   }
 
@@ -94,23 +86,10 @@ sub parse {
 
   return unless( @l==2 );
 
-  $I->server_name=$l[0];
-
   if( defined $I->server_map ) {
     if( length $I->server_map ) {
-      unless( ref( $I->server_map ) eq 'HASH' ) {
-	my $map=eval $I->server_map;
-	if( ref( $map ) eq 'HASH' ) {
-	  $I->server_map=$map;
-	} else {
-	  (undef, $I->server_map)=
-	    Apache2::ClickPath::_parse::MachineTable( $I->server_map );
-	}
-      }
-
-      $I->server_id=$I->server_map->{$l[0]}->[0]
-	if( ref( $I->server_map ) eq 'HASH' and
-	    exists $I->server_map->{$l[0]} );
+      warn "WARNING: ".__PACKAGE__.": server_map( FILENAME ) not implemented yet.\n";
+      $I->server_id=$l[0];
     } else {
       $I->server_id=$l[0];
     }
@@ -118,51 +97,21 @@ sub parse {
     my $len4=do {use integer; (length( $l[0] )+3)/4;};
     $len4*=4;
     $I->server_id=
-      join
-	( '.',
-	  unpack("C*",
-		 MIME::Base64::decode_base64($l[0].
-					     ('='x($len4-length( $l[0] ))))) );
+      join( '.',
+	    unpack("C*",
+		   MIME::Base64::decode_base64($l[0].
+					       ('='x($len4-length( $l[0] ))))) );
   }
 
   my $len4=do {use integer; (length( $l[1] )+3)/4;};
   $len4*=4;
-  $l[1]=MIME::Base64::decode_base64( $l[1].('='x($len4-length( $l[1] ))) );
-  if( $I->secret ) {
-    my $secret=Apache2::ClickPath::_parse::Secret( $I->secret );
-    my $iv;
-    if( length $I->secret_iv ) {
-      $iv=substr( Digest::MD5::md5( $I->secret_iv ), 0, 8 );
-    } else {
-      $iv="abcd1234";
-    }
-    my $crypt=Crypt::CBC->new(
-			      -key=>$secret,
-			      -keysize=>length($secret),
-			      -cipher=>'Crypt::Blowfish',
-			      -literal_key=>1,
-			      -header=>'none',
-			      -iv=>$iv,
-			     );
-    $l[1]=$crypt->decrypt( $l[1] );
-  }
-
-  my $crc;
-  if( length( $l[1] ) ) {
-    $crc=Digest::CRC::crc8( substr( $l[1], 1 ) );
-  } else {
-    $crc=-1;			# invalid value
-  }
-
-  @l=unpack( "CNNnN", $l[1] );
-
-  die "Invalid session: CRC checksum failed" if( $crc!=$l[0] );
-
-  (undef,
-   $I->creation_time,
+  ($I->creation_time,
    $I->server_pid,
    $I->seq_number,
-   $I->connection_id)=@l;
+   $I->connection_id)=
+     unpack( "NNnNn",
+	     MIME::Base64::decode_base64( $l[1].
+					  ('='x($len4-length( $l[1] ))) ) );
 
   return $I;
 }
@@ -213,10 +162,6 @@ parameters are recognized:
 
 =item B<server_map>
 
-=item B<secret>
-
-=item B<secret_iv>
-
 for these 3 see the appropriate member functions below.
 
 =item B<session>
@@ -278,20 +223,12 @@ a friendly session as the directive in your C<httpd.conf> does.
 
 if left undefined C<parse()> will interpret the server-id part
 of a session identifier as IP address. If set to an empty string it will
-not. If set to a non-empty string it will be interpreted the same way as
-C<Apache2::ClickPath> interprets a C<ClickPathMachineTable>. This table
-is then used to map a server name to a server_id (IP address).
-
-Also a HASH can be given instead of a string. Then this hash maps the
-server_name to a server_id.
-
-=item B<secret>
-
-=item B<secret_iv>
-
-these 2 functions correspond to the C<ClickPathSecret> and C<ClickPathSecretIV>
-configuration directives of L<Apache2::ClickPath>. Syntax and semantic are the
-same.
+not. In a future version of C<Apache2::ClickPath> I plan to provide
+directives to give a table of (IP adress, machine name) pairs in the
+C<httpd.conf>. Then all machines of a cluster can run with the same
+configuration files. Then the decoder will also be extented to map these
+names back and this attribute will be allowed to be assigned a non-empty
+string, too.
 
 =item B<session>
 
@@ -304,8 +241,6 @@ called it contains the session identifier.
 
 =item B<server_id>
 
-=item B<server_name>
-
 =item B<creation_time>
 
 =item B<server_pid>
